Flutterwave class

Constructors

Flutterwave({required String publicKey, required String txRef, required String amount, required Customer customer, required String paymentOptions, required Customization customization, required String redirectUrl, required bool isTestMode, required String currency, String? paymentPlanId, List<SubAccount>? subAccounts, Map? meta})

Properties

amount ↔ String
getter/setter pair
currency ↔ String
getter/setter pair
customer ↔ Customer
getter/setter pair
customization ↔ Customization
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isTestMode ↔ bool
getter/setter pair
meta ↔ Map?
getter/setter pair
paymentOptions ↔ String
getter/setter pair
paymentPlanId ↔ String?
getter/setter pair
publicKey ↔ String
getter/setter pair
redirectUrl ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAccounts ↔ List<SubAccount>?
getter/setter pair
txRef ↔ String
getter/setter pair

Methods

charge(BuildContext context) → Future<ChargeResponse>
Starts a transaction by calling the Standard service
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited